@@ -20,9 +20,9 @@ import (
 	"fmt"
 	"strings"
 
+	sourcev1 "github.com/fluxcd/source-controller/api/v1"
+
 	"github.com/fluxcd/flux2/v2/internal/utils"
-	"github.com/fluxcd/pkg/oci"
-	sourcev1 "github.com/fluxcd/source-controller/api/v1beta2"
 )
 
 var supportedSourceOCIProviders = []string{
@@ -32,13 +32,6 @@ var supportedSourceOCIProviders = []string{
 	sourcev1.GoogleOCIProvider,
 }
 
-var sourceOCIProvidersToOCIProvider = map[string]oci.Provider{
-	sourcev1.GenericOCIProvider: oci.ProviderGeneric,
-	sourcev1.AmazonOCIProvider:  oci.ProviderAWS,
-	sourcev1.AzureOCIProvider:   oci.ProviderAzure,
-	sourcev1.GoogleOCIProvider:  oci.ProviderGCP,
-}
-
 type SourceOCIProvider string
 
 func (p *SourceOCIProvider) String() string {
@@ -68,12 +61,3 @@ func (p *SourceOCIProvider) Description() string {
 		strings.Join(supportedSourceOCIProviders, ", "),
 	)
 }
-
-func (p *SourceOCIProvider) ToOCIProvider() (oci.Provider, error) {
-	value, ok := sourceOCIProvidersToOCIProvider[p.String()]
-	if !ok {
-		return 0, fmt.Errorf("no mapping between source OCI provider %s and OCI provider", p.String())
-	}
-
-	return value, nil
-}
