@@ -26,6 +26,7 @@ import (
 	"path"
 	"time"
 
+	"github.com/fluxcd/pkg/git/github"
 	cryptssh "golang.org/x/crypto/ssh"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -83,7 +84,7 @@ func Generate(options Options) (*manifestgen.Manifest, error) {
 
 	var dockerCfgJson []byte
 	if options.Registry != "" {
-		dockerCfgJson, err = generateDockerConfigJson(options.Registry, options.Username, options.Password)
+		dockerCfgJson, err = GenerateDockerConfigJson(options.Registry, options.Username, options.Password)
 		if err != nil {
 			return nil, fmt.Errorf("failed to generate json for docker config: %w", err)
 		}
@@ -148,6 +149,10 @@ func buildSecret(keypair *ssh.KeyPair, hostKey, dockerCfg []byte, options Option
 		return
 	}
 
+	if options.Address != "" {
+		secret.StringData[AddressSecretKey] = options.Address
+	}
+
 	if options.Username != "" && options.Password != "" {
 		secret.StringData[UsernameSecretKey] = options.Username
 		secret.StringData[PasswordSecretKey] = options.Password
@@ -158,17 +163,12 @@ func buildSecret(keypair *ssh.KeyPair, hostKey, dockerCfg []byte, options Option
 
 	if len(options.CACrt) != 0 {
 		secret.StringData[CACrtSecretKey] = string(options.CACrt)
-	} else if len(options.CAFile) != 0 {
-		secret.StringData[CAFileSecretKey] = string(options.CAFile)
 	}
 
 	if len(options.TLSCrt) != 0 && len(options.TLSKey) != 0 {
 		secret.Type = corev1.SecretTypeTLS
 		secret.StringData[TLSCrtSecretKey] = string(options.TLSCrt)
 		secret.StringData[TLSKeySecretKey] = string(options.TLSKey)
-	} else if len(options.CertFile) != 0 && len(options.KeyFile) != 0 {
-		secret.StringData[CertFileSecretKey] = string(options.CertFile)
-		secret.StringData[KeyFileSecretKey] = string(options.KeyFile)
 	}
 
 	if keypair != nil && len(hostKey) != 0 {
@@ -181,6 +181,32 @@ func buildSecret(keypair *ssh.KeyPair, hostKey, dockerCfg []byte, options Option
 		}
 	}
 
+	if len(options.VerificationCrts) != 0 {
+		for _, crts := range options.VerificationCrts {
+			secret.StringData[crts.Name] = string(crts.CACrt)
+		}
+	}
+
+	if len(options.TrustPolicy) != 0 {
+		secret.StringData[TrustPolicyKey] = string(options.TrustPolicy)
+	}
+
+	if options.GitHubAppID != "" {
+		secret.StringData[github.AppIDKey] = options.GitHubAppID
+	}
+
+	if options.GitHubAppInstallationID != "" {
+		secret.StringData[github.AppInstallationIDKey] = options.GitHubAppInstallationID
+	}
+
+	if options.GitHubAppPrivateKey != "" {
+		secret.StringData[github.AppPrivateKey] = options.GitHubAppPrivateKey
+	}
+
+	if options.GitHubAppBaseURL != "" {
+		secret.StringData[github.AppBaseUrlKey] = options.GitHubAppBaseURL
+	}
+
 	return
 }
 
@@ -223,7 +249,7 @@ func resourceToString(data []byte) string {
 	return string(data)
 }
 
-func generateDockerConfigJson(url, username, password string) ([]byte, error) {
+func GenerateDockerConfigJson(url, username, password string) ([]byte, error) {
 	cred := fmt.Sprintf("%s:%s", username, password)
 	auth := base64.StdEncoding.EncodeToString([]byte(cred))
 	cfg := DockerConfigJSON{
